#!/bin/sh

qt_args() {
    local args=""

    local args_evdevhotplug=$(printf "-plugin evdevhotplug:%s:%s:%s:%s" \
        "dir=/dev/input" \
        "mask=mouse.*" \
        "internalkey=/dev/input/by-keymap/internal" \
        "externalkey=/dev/input/by-keymap/external")

    local args_medusainput=$(printf "-plugin medusainput:%s:%s:%s" \
        "dir=/dev/input/rotary" \
        "filter-while-pressed" \
        "filter-timeout=50")

    if [ "none" = "$DISPSIZE" ]; then
        args="-platform nulloutput $args"
    elif [ "mx28" = "$PROCESSOR_FAMILY" ]; then
        args="-platform linuxfb $args"
    elif [ "${PROCESSOR_FAMILY}:${PROC_SUB_FAMILY}" = "mx6:ull" ]; then
        args="-platform linuxfb $args"
    elif [ "$FAMILYID" = "Trapper" ]; then
        args="-platform linuxfb $args"
    else
        if [ "$FAMILYID" = "Lisa" ]; then
            local cursor_tout=0
        fi
        args="-platform navicofb:${FRAMEBUFFER}${cursor_tout+:cursortimeout=${cursor_tout}} $args"
    fi

    case "${FAMILYID}" in
        Cougar|Bobo)
            args="$args $args_evdevhotplug -plugin evdevtouch -plugin tslib"
            ;;
        Cassius|Norris|Forefraz)
            args="$args $args_evdevhotplug -plugin evdevtouch -plugin navicorotary:/dev/input/rotary"
            ;;
        Hatchetfish|Lisa|Clinton|Floyd*|Porky|Dubya|Bluefin|Gable|Vladimir|Komodo)
            args="$args $args_evdevhotplug -plugin evdevtouch"
            ;;
        Anchovy)
            args="$args $args_evdevhotplug -plugin navicorotary:/dev/input/rotary"
            ;; 
        Trapper)
            args="$args $args_medusainput"
            ;;
        *)
            args="$args $args_evdevhotplug"
            ;;
    esac

    local webengine_args="--expose-gc"
    args="$args $webengine_args"

    printf "%s" "$args"
}

qpa_keymap() {
    local args=${QT_QPA_ARGS:-$(qt_args)}
    local keymap_file
    local keymap_codename="$CODENAME"

    case "$CODENAME" in
    charlie*)
        keymap_codename=charlie
        ;;
    esac

    for keymap_file in "$keymap_codename" \
                       "$(echo "$FAMILYID" | tr '[:upper:]' '[:lower:]')" \
                       simrad lowrance \
    ; do
        keymap_file="/usr/share/NOS/resources/${keymap_file}.qmap"
        if [ -s "$keymap_file" ]; then
            case "${FAMILYID}" in
            Trapper)
                local extra_args="keymap=${keymap_file}"
                args=${QT_QPA_ARGS/medusainput/medusainput:$extra_args}
                ;;
            *)
                local extra_args="internalkeymap=${keymap_file}"
                args=${QT_QPA_ARGS/evdevhotplug/evdevhotplug:$extra_args}
                ;;
            esac
            break
        fi
    done

    printf "%s" "$args"
}

export QT_QPA_FONTDIR="/usr/share/fonts"

# Prevent duplicated evdev keyboards, from linuxfb and evdevhotplug.
export QT_QPA_FB_DISABLE_INPUT=1

export QT_QPA_ARGS=$(qt_args)
export QT_QPA_ARGS_KEYMAP=$(qpa_keymap)

unset qt_args
unset qpa_keymap
