codename_to_hostname() {
    local host

    # If hostname is unspecified (or invalid) assemble a default
    case $CODENAME in
        hatchetfish)          host=NSO2 ;;
        muriwai)              host=Z2BB ;;
        radar)                host=Radar ;;
        cassius)              host=NSS2 ;;
        clinton)              host=HDS3 ;;
        dubya)                host=HDSC ;;
        vladimir)             host=HDSLive ;;
        norris)               host=NSS3 ;;
        tortuga)              host=ZEUS3 ;;
        copperfield)          host=VV703 ;;
        sonarhub)             host=SonarHub ;;
        luigi)                host=SonarHub3D ;;
        newton)               host=S3DHD ;;
        yoshi)                host=S5100 ;;
        lubeck)               host=ZEUS2W ;;
        penn|teller)          host=VV2 ;;
        floydbandg|vulcan*)   host=Vulcan ;; # Will match first before the next line
        floyd*)               host=GO ;;
        thor)                 host=E5000 ;;
        bobo|porky)           host=EliteTi ;;
        cartman)              host=EliteTi2 ;;
        foreman)
            case "$SUBFAMILYID" in
            0)                host=S2009 ;;
            1)                host=S2016 ;;
            esac
            ;;
        dynamo)               host=VV903 ;;
        frazier)
            case "$SUBFAMILYID" in
            0)                host=R2009 ;;
            1)                host=R3016 ;;
            esac
            ;;
        lisa)                 host=R5000 ;;
        pukeko)               host=VV403 ;;
        kard)                 host=Hook2 ;;
        bruce)                host=HookReveal ;;
        gilligan)             host=S3009 ;;
        bluefin)              host=NSO3 ;;
        tobago)               host=Zeus3GH ;;
        gable)                host=I3005-I3007 ;;
        gablegps)             host=P2005 ;;
        gablegpsimo)          host=P3007 ;;
        charliesimrad)        host=IS42J ;;
        charlieyanmar)        host=YD42 ;;
        bellagio)             host=LiveSight ;;
        stratosphere)         host=AI3D ;;
        trapper)              host=AP70Mk2 ;;
        anchovy)              host=Cruise;;
        blackjack)            host=LiveSonar ;; # TODO (HFP-4552): change LiveSonar to final product name when its decided 
        *)  host=${CODENAME:-unknown}
            printf '%s: Unknown CODENAME "%s".\n' "$0" "$CODENAME" 1>&2
            ;;
    esac

    printf "%s\n" "$host"
}

codename_to_model() {
    local model

    case "${CODENAME}-${SUBFAMILYID}" in
        hatchetfish-*)  model="NSO evo2" ;;
        muriwai-*)      model="Zeus2 Black Box" ;;
        cassius-0)      model="NSS7 evo2" ;;
        cassius-1)      model="NSS9 evo2" ;;
        cassius-2)      model="NSS12 evo2" ;;
        cassius-3)      model="NSS16 evo2" ;;
        norris-0)       model="NSS7 evo3" ;;
        norris-1)       model="NSS9 evo3" ;;
        norris-2)       model="NSS12 evo3" ;;
        norris-3)       model="NSS16 evo3" ;;
        lubeck-0)       model="Zeus2 W7" ;;
        lubeck-1)       model="Zeus2 W9" ;;
        lubeck-2)       model="Zeus2 W12" ;;
        lubeck-3)       model="Zeus2 W16" ;;
        tortuga-*)      model="Zeus3" ;;
        clinton-0)      model="HDS3-5" ;;
        clinton-1)      model="HDS3-7" ;;
        clinton-2)      model="HDS3-9" ;;
        clinton-3)      model="HDS3-12" ;;
        dubya-0)        model="HDSC-7" ;;
        dubya-1)        model="HDSC-9" ;;
        dubya-2)        model="HDSC-12" ;;
        dubya-3)        model="HDSC-16" ;;
        vladimir-0)     model="HDSLive-7" ;;
        vladimir-1)     model="HDSLive-9" ;;
        vladimir-2)     model="HDSLive-12" ;;
        vladimir-3)     model="HDSLive-16" ;;
        floyd-0)        model="GO7" ;;
        floydfs-0)      model="GO7 XSE" ;;
        floydjr-0)      model="GO5 XSE" ;;
        floydsr-0)      model="GO9 XSE" ;;
        floydmv-0)      model="GO12 XSE" ;;
        floydrm-0)      model="GO7 XSR" ;;
        floydbandg-0)   model="Vulcan 7" ;;
        vulcanfs-0)     model="Vulcan 7 FS" ;;
        vulcanjr-0)     model="Vulcan 5 FS" ;;
        vulcansr-0)     model="Vulcan 9" ;;
        vulcanmv-0)     model="Vulcan 12" ;;
        vulcanrm-0)     model="Vulcan 7R" ;;
        teller-*)       model="VV502" ;;
        thor-*)         model="E5000" ;;
        bobo-0)         model="Elite7-Ti" ;;
        bobo-1)         model="Elite9-Ti" ;;
        bobo-2)         model="Elite12-Ti" ;;
        porky-0)        model="Elite5-Ti" ;;
        foreman-0)      model="S2009" ;;
        foreman-1)      model="S2016" ;;
        frazier-0)      model="R2009" ;;
        frazier-1)      model="R3016" ;;
        penn-*)         model="VV702" ;;
        copperfield-0)  model="VV703" ;;
        lisa-*)         model="R5000" ;;
        dynamo-*)       model="VV903" ;;
        gilligan-2)      model="S3009" ;;
        kard-*)         model="Hook2" ;;
        bruce-*)        model="HookReveal" ;;
        bluefin-*)      model="NSO evo3" ;;
        tobago-*)       model="Zeus3 Glass Helm" ;;
        gable-*)        model="I3005 I3007" ;;
        gablegps-*)     model="P2005" ;;
        gablegpsimo-*)  model="P3007" ;;
        cartman-0)      model="Elite7-Ti2" ;;
        cartman-1)      model="Elite9-Ti2" ;;
        cartman-2)      model="Elite12-Ti2" ;;
        trapper-*)      model="AP70 Mk2" ;;
        anchovy-*)      model="Cruise" ;;
        komodohub-*)    model="IDS HUB" ;;
        *)              model="Unknown" ;;
    esac

    printf "%s\n" "$model"
}
