#!/bin/sh

start_service() {
    PIDFILE=${PIDFILE:-"/run/${SERVICE_NAME:-${0##*/}}.pid"}

    if [ -s "$PIDFILE" ] && kill -0 $(cat "$PIDFILE") 2>/dev/null; then
        printf '%s: Already running\n' "$0" >&2
        return 0
    fi

    {
        ${SERVICE_HANDLER:-service_main} "$@"

        rm -f "$PIDFILE"
    } &

    echo $! >"$PIDFILE"
}

stop_service() {
    PIDFILE=${PIDFILE:-"/run/${SERVICE_NAME:-${0##*/}}.pid"}

    if [ -s "$PIDFILE" ]; then
        local pid=$(cat "$PIDFILE")
        local timeout=100 # 10 seconds

        killtree $pid 2>/dev/null

        while kill -0 $pid 2>/dev/null; do
            if [ $((timeout--)) -eq 0 ]; then
                printf '%s: Timeout waiting for process to stop\n' "$0" >&2
                break
            fi

            sleep 0.1
        done
    else
        printf '%s: Not running\n' "$0" >&2
    fi

    rm -f "$PIDFILE"
}
