datestamp_ge() {
    # Returns 0 (true) if LHS-datestamp >= RHS-datestamp, non-zero (false) otherwise.
    # DATESTAMP's are 14 digits long and formatted YYYYMMDDHHMMSS (eg: 20140606121145).
    local lhs=$1 rhs=$2

    if [ ${#lhs} -ne ${#rhs} -o -n "${lhs//[0-9]/}" -o -n "${rhs//[0-9]/}" ]; then
        # Invalid input: different lengths, or non-numeric.
        printf 'WARNING: datestamp_ge(%s): Invalid input.\n' "$*" >&2
        return 2
    else
        # Shell math is signed 32bit, so largest value is 2^31-1 = 2147483647.
        # Shell also treats numbers with leading zeros as octal (facepalm).
        base10() { echo $(( ${1#${1%%[1-9]*}} )); }

        local lhs_ymd=$(base10 ${lhs:0:8}) rhs_ymd=$(base10 ${rhs:0:8})   # eg "20140606"
        local lhs_hms=$(base10 ${lhs:8}  ) rhs_hms=$(base10 ${rhs:8}  )   # eg "121145"

        if [ $lhs_ymd -gt $rhs_ymd ]; then
            return 0
        elif [ $lhs_ymd -lt $rhs_ymd ]; then
            return 1
        elif [ $lhs_hms -ge $rhs_hms ]; then
            return 0
        else
            return 1
        fi
    fi
}

get_factory_datestamp() {
    local mtpt='/etc/NOS' file='factory-install.txt'
    local datestamp umount_reqd

    if ! mountpoint -q "$mtpt"; then
        # Not in the RFS - assume initramfs.
        mtpt="/mnt${mtpt}"

        if ( ! mountpoint -q "$mtpt" ) && mkdir -p "$mtpt" && mount "$mtpt"; then
            umount_reqd=true
        fi
    fi

    # DATESTAMP must be 14 digits long to be accepted.
    datestamp=$(sed -ne 's/^DATESTAMP=\([0-9]\{14\}\)\s*$/\1/p' <"${mtpt}/${file}" || true)

    if [ "${umount_reqd:-}" = "true" ]; then
        umount "$mtpt"
    fi

    # Default to 1-Jan-2010 if no date recorded.
    printf '%s\n' "${datestamp:-20100101000000}"
}

check_factory_datestamp() {
    # Returns true when DATESTAMP >= FACTORY_DATESTAMP or comparison fails.
    local datestamp=$1

    # Cache result in a global variable.
    FACTORY_DATESTAMP=${FACTORY_DATESTAMP-$(get_factory_datestamp)}

    if datestamp_ge "$datestamp" "$FACTORY_DATESTAMP" || [ $? -eq 2 ]; then
        return 0
    else
        return 1
    fi
}
