#!/bin/sh

set -u

source /lib/functions/navico_env.sh
source /lib/functions/service.sh

SYS=/sys/class/graphics
MAXFD=10

set_depth() {
    local depth=$1

    if [ "$depth" = "auto" ]; then
        case "$FAMILYID" in
        FloydMv)
            depth=16 ;;  # HFP-2681: Override colour depth for performance.
        *) 
            depth=$(cut -f3 /proc/navico_platform/disp_intf) ;;
        esac
    fi

    case $depth in
    16|16bpp|18|18bpp)
        depth=16 ;;
    24|24bpp|32|32bpp)
        depth=32 ;;
    *)
        printf 'Unrecognised bpp: "%s"\n' "$depth"
        return 1
        ;;
    esac

    local old=$(cat $SYS/fb0/bits_per_pixel)

    if [ $depth != $old ]; then
        local rotation

        navico_env_init

        if [ -x /usr/bin/fbrotate ] && fbrotate -s 0 2>/dev/null && [ "${FRAMEBUFFER##*[^0-9]}" != "0" ]; then
            # Rotation or copy task was running.
            # Determine output rotation setting so task will be restarted after bpp set.
            rotation=$(cut -f4 /proc/navico_platform/disp_intf)
        fi

        for i in $(seq $MAXFD -1 0) ; do
            if [ -e /dev/fb$i ]; then
                fbdraw --framebuffer /dev/fb$i --set-bpp $depth &
            fi
        done
        wait

        if [ -n "${rotation:-}" ]; then
            if [ "$FAMILYID" = "Bluefin" ]; then
                SERVICE_NAME="fbrotate-fb0"
                SERVICE_HANDLER=fbrotate
                stop_service
                start_service -r $rotation --gpu2d -o /dev/fb0
            else
                fbrotate -r $rotation --ipu 0 -o /dev/fb0 >/dev/null
            fi
        fi

        if [ -e /dev/mxc_hdmi ]; then
            /lib/udev/udev_hdmi_action.sh --probe
            true # suppress exit code (usually non-zero)
        fi
    fi
}

show_depth() {
    for i in $(seq 0 $MAXFD); do
        if [ -e $SYS/fb$i ]; then
            printf '/dev/fb%d %d\n' "$i" "$(cat $SYS/fb$i/bits_per_pixel)"
        fi
    done
}

case ${1:-} in
    set)
        shift && set_depth "$@"
        ;;
    get)
        show_depth
        ;;
    *)
        printf "Usage: %s { set <auto|16|32> | get }\n" "${0##*/}" >&2
        exit 1
        ;;
esac
