#!/bin/sh

manufacturer_id() {
    local char=".ABCDEFGHIJKLMNOPQRSTUVWXYZ....." # 0-31
    local edid=$1
    local m1 m2 m3
    if [ -e $edid ] ; then
	head -n1 $edid | cut -d' ' -f 9,10 | if read a b ; then
	    m1="${char:$(((a>>2)&31)):1}"
	    m2="${char:$((((a&3)<<3)|((b>>5)&7))):1}"
	    m3="${char:$((b&31)):1}"
	    echo ${m1}${m2}${m3}
	fi
    fi
}

product_family () {
    local edid=$1
    printf "%d" $(head -n1 $edid | cut -d' ' -f 12)
}

product_code () {
    local edid=$1
    printf "%d" $(head -n1 $edid | cut -d' ' -f 11)
}

# NME product family 0 = rocky, except product codes 0,1,2
isrocky () {
    local edid=$1
    [ $(manufacturer_id $edid) = "NME" ] && [ $(product_family $edid) = 0 ] && [ $(product_code $edid) -ge 3 ]
}

# TBD: read string from EDID descriptor
rocky_name () {
    local id=$1
    case $id in
	# Simrad
	3) echo "MO16-T" ;;
	4) echo "MO16-P" ;;
	5) echo "MO19-T" ;;
	6) echo "MO19-P" ;;
	7) echo "MO24-T" ;;
	8) echo "MO24-P" ;;
	9) echo "MO27-T" ;;
	10) echo "MO27-P" ;;
	11) echo "MO16-PRO" ;;
	12) echo "MO19-PRO" ;;
	13) echo "MO24-PRO" ;;
	14) echo "MO27-PRO" ;;

	# B&G
	15) echo "ZM16-T" ;;
	16) echo "ZM19-T" ;;
	17) echo "ZM24-T" ;;
	18) echo "ZM27-T" ;;
	*) echo "unknown" ;;
    esac
}

if [ "$1" = "-v" ]; then
    shift
    verbose=1
fi

EDID=${1:-/sys/devices/soc0/soc/20e0000.hdmi_video/edid}

if [ -e $EDID ] && isrocky $EDID ; then
    [ "$verbose" = "1" ] && rocky_name $(product_code $EDID)
    exit 0
fi

[ "$verbose" = "1" ] && echo "Not a Rocky"
exit 1
