if ! command -v have_emmc >/dev/null 2>&1; then
    source /lib/functions/have_emmc.sh
fi

have_mtd() {
    [ -d "/sys/class/mtd/mtd0" ]
}

get_storage_type() {
    if have_emmc && ! have_mtd; then
        echo "emmc"
    elif have_emmc && have_mtd; then
         echo "emmc-nand"
    elif have_mtd; then
        echo "nand"
    else
        echo "unknown"
    fi
}

show() {
    printf '%s\t' "$@"
    printf '\n'
}

show_bytes() {
    local name=$1 size=$2; shift 2
    show "$name" "$size" "$@"
}

show_bytes_from_sectors() {
    local name=$1 size=$2;shift 2
    bytes=`echo $size | awk '{
        print($size*512)
    }'`

    show "$name" "$bytes" "$@"
}

head_files() {
    local base=$1 val; shift

    for name; do
        if val=$(cat "${base}/${name}") 2>/dev/null; then
            show "name" "$val"
        fi
    done
}

get_emmc_details(){
    have_emmc
    head_files "$EMMC_SYSFS" name

    local blk_sysfs blk_dev blk_part name attr val

    for blk_sysfs in ${EMMC_SYSFS}/block/*/; do
        blk_dev=${blk_sysfs%/}
        blk_dev=${blk_dev##*/}

        for blk_part in ${blk_sysfs}; do
            [ -d "$blk_sysfs" ] || continue

            name=${blk_part%/}
            name=${name##*/}

            for attr in size; do
                [ -e "${blk_part}/${attr}" ] || continue
                val=$(cat "${blk_part}/${attr}" 2>/dev/null) || continue

                show_bytes_from_sectors "${attr}" "$val"
            done
        done
    done

}

get_nand_details(){
    local name mtd_sysfs=/sys/devices/virtual/mtd
    local mx51_nand=/sys/devices/platform/mxc_nandv2_flash.0

    head_files "${mtd_sysfs}/mtd0" nand_type

    local total_size=0 
    local type size name

    while read type size name; do
        case $type in
        mtd[0-9]:)
            total_size=$(( total_size + 0x${size} ))
            ;;
        esac
    done </proc/mtd

    show_bytes "size" "$total_size"

}

get_storage_details(){

    case ${1:-} in
        emmc)
            get_emmc_details
            ;;
        nand)
            get_nand_details
            ;;
    esac
}

