#!/bin/sh

# udhcpc script edited by Tim Riker <Tim@Rikers.org>

[ -z "$1" ] && echo "Error: should be called from udhcpc" && exit 1

RESOLV_CONF="/etc/resolv.conf"
[ -n "$broadcast" ] && BROADCAST="broadcast $broadcast"
[ -n "$subnet" ] && NETMASK="netmask $subnet"

wait_ll_addr() {
  # Wait up to 30 seconds for the link local address to be assigned to $interface
  local ll_intf=${interface%%:*} timeout=30

  while [ $((timeout--)) -gt 0 ]; do
    local ip_addr=$(ip addr show dev $ll_intf to 169.254/16)
    [ -n "$ip_addr" ] && break
    sleep 1
  done
}


case "$1" in
	deconfig)
		ifconfig ${interface%%:*} up
		;;

	leasefail)
		: # Unable to obtain lease (but udhcpc will continue to retry).
		;;

	renew|bound)
		if [ "${interface:0:4}" = "eth0" ]; then
			wait_ll_addr
		fi

		/sbin/ifconfig $interface $ip $BROADCAST $NETMASK

		if [ -x /etc/static-routes ]; then
			/etc/static-routes
		fi

		if [ -n "$router" ] ; then
			echo "deleting routers"
			while route del default gw 0.0.0.0 dev $interface ; do
				:
			done

			case $interface in
			    wlan0*) metric=10 ;;
			    eth0*) metric=20 ;;
			    *) metric=50 ;;
			esac

			for i in $router ; do
				route add default gw $i dev $interface metric $metric
			done

		fi

		echo -n > $RESOLV_CONF
		chmod 644 $RESOLV_CONF
		[ -n "$domain" ] && echo search $domain >> $RESOLV_CONF
		for i in $dns ; do
			echo adding dns $i
			echo nameserver $i >> $RESOLV_CONF
		done

		# Restart the ntpd daemon on new connection
		[ -x /etc/rc.d/rc.ntpd ] && /etc/rc.d/rc.ntpd restart
		;;
esac

exit 0
