#! /bin/sh
# Configure alias address for use by weather module

set -u

WM_INTERFACE="eth0"
WM_ARP_TIMEOUT=5

add_interface()
{
    local wm_interface_alias=$1
    local wm_netmask=$2
    local wm_base_address=$3
    
    local ip_addr=`ifconfig ${wm_interface_alias} | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}'`
    ip_addr=`echo ${ip_addr} | awk -F"\." ' $1 <= 255 && $2 <= 255 && $3 <= 255 && $4 <= 255 '`

    if [ -n "${ip_addr}" ]; then
        echo "Already configured "${wm_interface_alias}
        return 0
    fi

    ip_addr=`ifconfig ${WM_INTERFACE} | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}'`
    ip_addr=`echo ${ip_addr} | awk -F"\." ' $1 <= 255 && $2 <= 255 && $3 < 255 && $4 <= 255 '`	
    if [ -n "${ip_addr}" ]; then
        local ip_addr_0=`echo ${ip_addr} | cut -d. -f1`
        local ip_addr_1=`echo ${ip_addr} | cut -d. -f2`
        local ip_addr_2=`echo ${ip_addr} | cut -d. -f3`
        local ip_addr_3=`echo ${ip_addr} | cut -d. -f4`
        
        # used to check which address format needs to be generated
        local mask_2=`echo ${wm_netmask} | cut -d. -f3`

        # generate base of address to use
        local base_test_ip=${wm_base_address}
        
        if [ ${mask_2} -eq 0 ]
        then
            if [ ${ip_addr_0} -eq 169 ]; then
                # zeroconf
                base_test_ip=${base_test_ip}${ip_addr_2}\.
            else
                # DHCP just use bottom 8 bits
                base_test_ip=${base_test_ip}255\.
            fi
        fi


        local tmpval=${ip_addr_3}

        while [ 1 ]
        do
            # Weather module uses 252, 253 and 254
            if [ ${tmpval} -ge 252 ]; then
                tmpval=1
            fi

            # generate a new IP address to check
            local test_ip=${base_test_ip}${tmpval}

            arping -D -w ${WM_ARP_TIMEOUT} ${test_ip}
            local ret=$?						
            if [ "${ret}" -eq 0 ]; then
                ifconfig ${wm_interface_alias} ${test_ip} netmask ${wm_netmask}
                return 0
            fi

            # increment address and try again
            tmpval=`expr ${tmpval} + 1`

            if [ $tmpval -eq ${ip_addr_3} ]; then
                # full circle bail
                return 1
            fi						 
        done
    fi
}

add_interface "eth0:weather" "255.255.0.0" "172.22."
add_interface "eth0:weatherwm4" "255.255.255.0" "172.22.255."
