#!/bin/sh

#set -e -x

### Get the family id to use below for selecting behaviour appropriate for that family.
source /lib/functions/navico_env.sh
navico_env_init

# only for use as a "zcip" callback script
[ -n "${interface:-}" ] || exit 1

# zcip should start on boot/resume and various media changes
case "$1" in
init)
	# for now, zcip requires the link to be already up,
	# and it drops links when they go down.  that isn't
	# the most robust model...
	exec ip link set dev $interface up
	;;

config)
        [ -n "${ip:-}" ] || exit 1

        if [ "${INTF_CONFIG:-}" = "DNT" ]; then
            # HFP-2362: Dual Network Transducer support
            ip address add local "${ip}/16" scope link dev $interface noprefixroute broadcast +
            # "noprefixroute" doesn't work as expected, manually delete the route
            ip route del to 169.254.0.0/16 dev $interface
            ip route add to 255.255.255.255/32 dev $interface metric 100
            exit 0
        fi

        ip address add local "${ip}/16" scope link dev $interface broadcast +
        ip route add to 224.0.0.0/4        dev $interface
        ip route add to 255.255.255.255/32 dev $interface

	if [ -x /usr/sbin/debugservices ]; then
		/usr/sbin/debugservices ip-init $interface
	fi

	if [ "$DISPSIZE" != "none" -a -x /usr/libexec/weather-module.sh ]; then
		/usr/libexec/weather-module.sh
	fi

	exit 0
	;;

deconfig)
        [ -n "${ip:-}" ] || exit 1

	if [ -x /usr/sbin/debugservices ]; then
		/usr/sbin/debugservices ip-remove $interface
	fi
	
	exec ip address del dev $interface local $ip
	;;
esac
exit 1
